@@ -41,13 +41,14 @@ int main(int argc, char *argv[])
     {
         // App details
         app.setApplicationName("photoflare");
-        app.setApplicationVersion("v1.6.10");
+        app.setApplicationVersion("1.6.12");
         app.setOrganizationDomain("photoflare.io");
 
         // Setup Default settings
         QString loc = QStandardPaths::locate(QStandardPaths::ConfigLocation, QString(), QStandardPaths::LocateDirectory)+"photoflare.io";
         if(!QDir(loc).exists())
         {
+            QDir().mkdir(loc);
             SETTINGS->setDefaultSettings();
         }
 
@@ -116,6 +117,14 @@ int main(int argc, char *argv[])
             {
                 lang = "es";
             }
+            else if(sysLanguage == "Japan")
+            {
+                lang = "ja";
+            }
+            else if(sysLanguage == "Turkey")
+            {
+                lang = "tr";
+            }
             SETTINGS->setUserLanguage(lang);
         }
 
@@ -123,7 +132,7 @@ int main(int argc, char *argv[])
         app.installTranslator(&translator);
 
         QStringList paths = QStandardPaths::standardLocations(QStandardPaths::DataLocation);
-        paths.prepend("."); //for local builds testing
+        //paths.prepend("."); //for local builds testing
         for(int i = 0;i < paths.length(); i++)
         {
             QFileInfo check_file(paths[i]+"/languages/"+SETTINGS->getUserLanguage()+".qm");
