@@ -21,6 +21,7 @@
 #include <QMainWindow>
 #include <QMdiArea>
 #include <QLabel>
+#include <QNetworkReply>
 
 #include "dialogs/batchdialog.h"
 
@@ -129,6 +130,7 @@ private slots:
     void on_actionFlip_Horizontal_triggered();
     void on_actionRotate_CCW_triggered();
     void on_actionRotate_CW_triggered();
+    void on_actionFree_Rotate_triggered();
     void on_actionImage_Size_triggered();
     void on_actionFilterbar_triggered();
     void on_actionToolpalette_triggered();
