@@ -26,17 +26,14 @@ class TextTool : public Tool
 {
     Q_OBJECT
 public:
-    TextTool(QObject *parent = 0);
-    ~TextTool();
+    TextTool(QObject *parent = nullptr);
+    ~TextTool() override;
 
     void setText(const QString &text, const QFont &font, const QColor&, const bool &antialiasEnabled, const QString &position);
-
     void onMousePress(const QPoint &pos, Qt::MouseButton button) override;
     void onMouseMove(const QPoint &pos) override;
     void onMouseRelease(const QPoint &pos) override;
-
     void disconnect() override;
-public slots:
 
 signals:
     void editText(const QString&, const QFont&, const QColor&);
@@ -45,11 +42,7 @@ signals:
 private:
     void previewText();
     void drawText();
-
     TextToolPrivate *d;
 };
 
-
-
 #endif // TEXTTOOL_H
-
